/*
 * @Copyright 2010, MechSoft 
 * MechSoft, Mechanical and Software Solutions 
 * 
 * Licensed under the Apache License, Version 2.0 (the 
 * "License"); you may not use this file except in compliance 
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.samples.jsonexample;

import org.defne.service.Message;
import org.defne.service.TransactionPolicy;
import org.defne.service.annotation.EntityManagerAttribute;
import org.defne.service.annotation.Operation;
import org.defne.service.annotation.Service;
import org.defne.service.annotation.TransactionAttribute;
import org.defne.utility.exception.DefneException;

@Service
public class HelloService
{
    @Operation
    public static Message sayHello(Message message) throws DefneException
    {
        String name = message.getMessageParameter(String.class, IHelloService.SayHelloOperation.INPUT.NAME);
        int salary  = message.getMessageParameter(Integer.class, IHelloService.SayHelloOperation.INPUT.SALARY);
        
        message.putMessageParameter(IHelloService.SayHelloOperation.OUTPUT.MESSAGE, "Salary of the " + name + " is " + salary);
        
        return message;
    }
    
    @Operation
    @EntityManagerAttribute(use=false)
    @TransactionAttribute(TransactionPolicy.NO_TRANSACTION)
    public static Message printPerson(Message message) throws DefneException
    {
        Person person = message.getMessageParameter(Person.class, IHelloService.PrintPersonOperation.INPUT.PERSON);
        System.out.println("Name : " + person.getName());
        System.out.println("City : " + person.getAdres().getCity());
        System.out.println("Country : " + person.getAdres().getCountry());
        
        return message;
    }

}
